{% extends 'generic/object.html' %}
{% load render_table from django_tables2 %}

{% block content %}
<div class="row mb-3">
    <div class="col col-md-6">
        <div class="card">
            <h5 class="card-header">{{ object.name }}</h5>
            <div class="card-body">
                <table class="table table-hover attr-table">
                    <tr>
                        <th scope="row">IP Addresses</th>
                        {% for address in object.ip_addresses.all %}
                            <td>
                                <a href="{{address.get_absolute_url}}">{{ address }}</a>
                            </td>
                        {% endfor %}
                    </tr>
                    <tr>
                        <th scope="row">ASN</th>
                        <td>
                            <a href="{{object.asn.get_absolute_url}}">{{ object.asn }}</a>
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        {% include 'inc/panels/custom_fields.html' %}
    </div>
    <div class="col col-md-6">
        {% include 'inc/panels/tags.html' %}
        {% include 'inc/panels/comments.html' %}
    </div>
</div>
{% endblock content %}
